@@ -39,6 +39,8 @@ from pybotx.client.exceptions.chats import (
     ChatCreationError,
     ChatCreationProhibitedError,
     InvalidUsersListError,
+    ThreadCreationError,
+    ThreadCreationProhibitedError,
 )
 from pybotx.client.exceptions.common import (
     ChatNotFoundError,
@@ -62,11 +64,12 @@ from pybotx.client.exceptions.users import UserNotFoundError
 from pybotx.client.smartapps_api.exceptions import SyncSmartAppEventHandlerNotFoundError
 from pybotx.client.smartapps_api.smartapp_manifest import (
     SmartappManifest,
+    SmartappManifestAndroidParams,
+    SmartappManifestAuroraParams,
+    SmartappManifestIosParams,
+    SmartappManifestUnreadCounterParams,
     SmartappManifestWebParams,
 )
-from pybotx.client.smartapps_api.sync_smartapp_event import (
-    SyncSmartAppEventResponsePayload,
-)
 from pybotx.client.stickers_api.exceptions import (
     InvalidEmojiError,
     InvalidImageError,
@@ -89,6 +92,7 @@ from pybotx.models.enums import (
     AttachmentTypes,
     ChatTypes,
     ClientPlatforms,
+    ConferenceLinkTypes,
     MentionTypes,
     SmartappManifestWebLayoutChoices,
     SyncSourceTypes,
@@ -126,11 +130,21 @@ from pybotx.models.method_callbacks import BotAPIMethodFailedCallback
 from pybotx.models.smartapps import SmartApp
 from pybotx.models.status import BotMenu, StatusRecipient
 from pybotx.models.stickers import Sticker, StickerPack
+from pybotx.models.sync_smartapp_event import (
+    BotAPISyncSmartAppEventErrorResponse,
+    BotAPISyncSmartAppEventResponse,
+    BotAPISyncSmartAppEventResultResponse,
+)
 from pybotx.models.system_events.added_to_chat import AddedToChatEvent
 from pybotx.models.system_events.chat_created import ChatCreatedEvent, ChatCreatedMember
+from pybotx.models.system_events.chat_deleted_by_user import ChatDeletedByUserEvent
+from pybotx.models.system_events.conference_changed import ConferenceChangedEvent
+from pybotx.models.system_events.conference_created import ConferenceCreatedEvent
+from pybotx.models.system_events.conference_deleted import ConferenceDeletedEvent
 from pybotx.models.system_events.cts_login import CTSLoginEvent
 from pybotx.models.system_events.cts_logout import CTSLogoutEvent
 from pybotx.models.system_events.deleted_from_chat import DeletedFromChatEvent
+from pybotx.models.system_events.event_delete import EventDeleted
 from pybotx.models.system_events.event_edit import EventEdit
 from pybotx.models.system_events.internal_bot_notification import (
     InternalBotNotificationEvent,
@@ -151,6 +165,9 @@ __all__ = (
     "BotAPIBotDisabledErrorData",
     "BotAPIBotDisabledResponse",
     "BotAPIMethodFailedCallback",
+    "BotAPISyncSmartAppEventErrorResponse",
+    "BotAPISyncSmartAppEventResponse",
+    "BotAPISyncSmartAppEventResultResponse",
     "BotAPIUnverifiedRequestErrorData",
     "BotAPIUnverifiedRequestResponse",
     "BotAccount",
@@ -176,15 +193,21 @@ __all__ = (
     "ChatCreatedMember",
     "ChatCreationError",
     "ChatCreationProhibitedError",
+    "ChatDeletedByUserEvent",
     "ChatInfo",
     "ChatInfoMember",
     "ChatListItem",
     "ChatNotFoundError",
     "ChatTypes",
     "ClientPlatforms",
+    "ConferenceChangedEvent",
+    "ConferenceCreatedEvent",
+    "ConferenceDeletedEvent",
+    "ConferenceLinkTypes",
     "DeletedFromChatEvent",
     "Document",
     "EditMessage",
+    "EventDeleted",
     "EventEdit",
     "EventNotFoundError",
     "File",
@@ -226,8 +249,11 @@ __all__ = (
     "RequestHeadersNotProvidedError",
     "SmartApp",
     "SmartAppEvent",
-    "SyncSmartAppEventResponsePayload",
     "SmartappManifest",
+    "SmartappManifestAndroidParams",
+    "SmartappManifestAuroraParams",
+    "SmartappManifestIosParams",
+    "SmartappManifestUnreadCounterParams",
     "SmartappManifestWebLayoutChoices",
     "SmartappManifestWebParams",
     "StatusRecipient",
@@ -238,6 +264,9 @@ __all__ = (
     "SyncSmartAppEventHandlerFunc",
     "SyncSmartAppEventHandlerNotFoundError",
     "SyncSourceTypes",
+    "ThreadCreationError",
+    "ThreadCreationEventNotFoundError",
+    "ThreadCreationProhibitedError",
     "UnknownBotAccountError",
     "UnknownSystemEventError",
     "UnsupportedBotAPIVersionError",
