@@ -1,20 +1,9 @@
 from asyncio import Task
+from collections.abc import AsyncIterable, AsyncIterator, Iterator, Mapping, Sequence
 from contextlib import asynccontextmanager
 from datetime import datetime
 from types import SimpleNamespace
-from typing import (
-    Any,
-    AsyncIterable,
-    AsyncIterator,
-    Dict,
-    Iterator,
-    List,
-    Mapping,
-    Optional,
-    Sequence,
-    Tuple,
-    Union,
-)
+from typing import Any, Dict, List, Optional, Set, Tuple, Union
 from uuid import UUID
 
 import aiofiles
@@ -56,6 +45,10 @@ from pybotx.client.chats_api.create_chat import (
     BotXAPICreateChatRequestPayload,
     CreateChatMethod,
 )
+from pybotx.client.chats_api.create_thread import (
+    BotXAPICreateThreadRequestPayload,
+    CreateThreadMethod,
+)
 from pybotx.client.chats_api.disable_stealth import (
     BotXAPIDisableStealthRequestPayload,
     DisableStealthMethod,
@@ -138,19 +131,24 @@ from pybotx.client.smartapps_api.smartapp_event import (
 from pybotx.client.smartapps_api.smartapp_manifest import (
     BotXAPISmartAppManifestRequestPayload,
     SmartappManifest,
+    SmartappManifestAndroidParams,
+    SmartappManifestIosParams,
     SmartAppManifestMethod,
+    SmartappManifestUnreadCounterParams,
+    SmartappManifestWebParams,
 )
 from pybotx.client.smartapps_api.smartapp_notification import (
     BotXAPISmartAppNotificationRequestPayload,
     SmartAppNotificationMethod,
 )
+from pybotx.client.smartapps_api.smartapp_unread_counter import (
+    BotXAPISmartAppUnreadCounterRequestPayload,
+    SmartAppUnreadCounterMethod,
+)
 from pybotx.client.smartapps_api.smartapps_list import (
     BotXAPISmartAppsListRequestPayload,
     SmartAppsListMethod,
 )
-from pybotx.client.smartapps_api.sync_smartapp_event import (
-    SyncSmartAppEventResponsePayload,
-)
 from pybotx.client.smartapps_api.upload_file import (
     UploadFileMethod as SmartappsUploadFileMethod,
 )
@@ -221,7 +219,7 @@ from pybotx.image_validators import (
     ensure_file_content_is_png,
     ensure_sticker_image_size_valid,
 )
-from pybotx.logger import logger, pformat_jsonable_obj, trim_file_data_in_incoming_json
+from pybotx.logger import log_incoming_request, logger, pformat_jsonable_obj
 from pybotx.missing import Missing, MissingOptional, Undefined
 from pybotx.models.async_files import File
 from pybotx.models.attachments import IncomingFileAttachment, OutgoingAttachment
@@ -230,7 +228,6 @@ from pybotx.models.bot_catalog import BotsListItem
 from pybotx.models.chats import ChatInfo, ChatListItem
 from pybotx.models.commands import BotAPICommand, BotCommand
 from pybotx.models.enums import ChatTypes
-from pybotx.models.enums import SmartappManifestWebLayoutChoices as WebLayoutChoices
 from pybotx.models.message.edit_message import EditMessage
 from pybotx.models.message.markup import BubbleMarkup, KeyboardMarkup
 from pybotx.models.message.message_status import MessageStatus
@@ -245,10 +242,11 @@ from pybotx.models.status import (
     build_bot_status_response,
 )
 from pybotx.models.stickers import Sticker, StickerPack, StickerPackFromList
-from pybotx.models.system_events.smartapp_event import (
-    BotAPISmartAppEvent,
-    SmartAppEvent,
+from pybotx.models.sync_smartapp_event import (
+    BotAPISyncSmartAppEvent,
+    BotAPISyncSmartAppEventResponse,
 )
+from pybotx.models.system_events.smartapp_event import SmartAppEvent
 from pybotx.models.users import UserFromCSV, UserFromSearch
 
 MissingOptionalAttachment = MissingOptional[
@@ -297,19 +295,13 @@ class Bot:
         verify_request: bool = True,
         request_headers: Optional[Mapping[str, str]] = None,
         logging_command: bool = True,
+        trusted_issuers: Optional[Set[str]] = None,
     ) -> None:
         if logging_command:
-            logger.opt(lazy=True).debug(
-                "Got command: {command}",
-                command=lambda: pformat_jsonable_obj(
-                    trim_file_data_in_incoming_json(raw_bot_command),
-                ),
-            )
+            log_incoming_request(raw_bot_command, message="Got command: ")
 
         if verify_request:
-            if request_headers is None:
-                raise RequestHeadersNotProvidedError
-            self._verify_request(request_headers)
+            self._verify_request(request_headers, trusted_issuers=trusted_issuers)
 
         try:
             bot_api_command: BotAPICommand = parse_obj_as(
@@ -338,23 +330,20 @@ class Bot:
         verify_request: bool = True,
         request_headers: Optional[Mapping[str, str]] = None,
         logging_command: bool = True,
-    ) -> SyncSmartAppEventResponsePayload:
+        trusted_issuers: Optional[Set[str]] = None,
+    ) -> BotAPISyncSmartAppEventResponse:
         if logging_command:
-            logger.opt(lazy=True).debug(
-                "Got sync smartapp event: {command}",
-                command=lambda: pformat_jsonable_obj(
-                    trim_file_data_in_incoming_json(raw_smartapp_event),
-                ),
+            log_incoming_request(
+                raw_smartapp_event,
+                message="Got sync smartapp event: ",
             )
 
         if verify_request:
-            if request_headers is None:
-                raise RequestHeadersNotProvidedError
-            self._verify_request(request_headers)
+            self._verify_request(request_headers, trusted_issuers=trusted_issuers)
 
         try:
-            bot_api_smartapp_event: BotAPISmartAppEvent = parse_obj_as(
-                BotAPISmartAppEvent,
+            bot_api_smartapp_event: BotAPISyncSmartAppEvent = parse_obj_as(
+                BotAPISyncSmartAppEvent,
                 raw_smartapp_event,
             )
         except ValidationError as validation_exc:
@@ -368,7 +357,7 @@ class Bot:
     async def sync_execute_smartapp_event(
         self,
         smartapp_event: SmartAppEvent,
-    ) -> SyncSmartAppEventResponsePayload:
+    ) -> BotAPISyncSmartAppEventResponse:
         self._bot_accounts_storage.ensure_bot_id_exists(smartapp_event.bot.id)
         return await self._handler_collector.handle_sync_smartapp_event(
             self,
@@ -380,6 +369,7 @@ class Bot:
         query_params: Dict[str, str],
         verify_request: bool = True,
         request_headers: Optional[Mapping[str, str]] = None,
+        trusted_issuers: Optional[Set[str]] = None,
     ) -> Dict[str, Any]:
         logger.opt(lazy=True).debug(
             "Got status: {status}",
@@ -387,9 +377,7 @@ class Bot:
         )
 
         if verify_request:
-            if request_headers is None:
-                raise RequestHeadersNotProvidedError
-            self._verify_request(request_headers)
+            self._verify_request(request_headers, trusted_issuers=trusted_issuers)
 
         try:
             bot_api_status_recipient = BotAPIStatusRecipient.parse_obj(query_params)
@@ -412,13 +400,12 @@ class Bot:
         raw_botx_method_result: Dict[str, Any],
         verify_request: bool = True,
         request_headers: Optional[Mapping[str, str]] = None,
+        trusted_issuers: Optional[Set[str]] = None,
     ) -> None:
         logger.debug("Got callback: {callback}", callback=raw_botx_method_result)
 
         if verify_request:
-            if request_headers is None:
-                raise RequestHeadersNotProvidedError
-            self._verify_request(request_headers)
+            self._verify_request(request_headers, trusted_issuers=trusted_issuers)
 
         callback: BotXMethodCallback = parse_obj_as(
             # Same ignore as in pydantic
@@ -1181,6 +1168,27 @@ class Bot:
 
         return botx_api_chat_id.to_domain()
 
+    async def create_thread(self, bot_id: UUID, sync_id: UUID) -> UUID:
+        """
+        Create thread.
+
+        :param bot_id: Bot which should perform the request.
+        :param sync_id: Message for which thread should be created
+
+        :return: Created thread uuid.
+        """
+
+        method = CreateThreadMethod(
+            bot_id,
+            self._httpx_client,
+            self._bot_accounts_storage,
+        )
+
+        payload = BotXAPICreateThreadRequestPayload.from_domain(sync_id=sync_id)
+        botx_api_thread_id = await method.execute(payload)
+
+        return botx_api_thread_id.to_domain()
+
     async def pin_message(
         self,
         *,
@@ -1560,17 +1568,18 @@ class Bot:
         self,
         *,
         bot_id: UUID,
-        web_default_layout: WebLayoutChoices = WebLayoutChoices.minimal,
-        web_expanded_layout: WebLayoutChoices = WebLayoutChoices.half,
-        web_always_pinned: bool = False,
+        ios: Missing[SmartappManifestIosParams] = Undefined,
+        android: Missing[SmartappManifestAndroidParams] = Undefined,
+        web_layout: Missing[SmartappManifestWebParams] = Undefined,
+        unread_counter: Missing[SmartappManifestUnreadCounterParams] = Undefined,
     ) -> SmartappManifest:
         """Send smartapp manifest with given parameters.
 
         :param bot_id: Bot which should perform the request.
-        :param web_default_layout: default smartapp layout for web clients.
-        :param web_expanded_layout: expanded smartapp layout for web clients.
-        :param web_always_pinned: True if smartapp icon should be always pinned
-            in the web clients sidebar.
+        :param ios: Smartapp layout for ios clients.
+        :param android: Smartapp layout for android clients.
+        :param web_layout: Smartapp layout for web clients.
+        :param unread_counter: Entities that can be subscribed to in the unread counter.
 
         :return: Smartapp manifest with the set parameters received from BotX.
         """
@@ -1581,9 +1590,10 @@ class Bot:
             self._bot_accounts_storage,
         )
         payload = BotXAPISmartAppManifestRequestPayload.from_domain(
-            web_default_layout=web_default_layout,
-            web_expanded_layout=web_expanded_layout,
-            web_always_pinned=web_always_pinned,
+            ios=ios,
+            android=android,
+            web_layout=web_layout,
+            unread_counter=unread_counter,
         )
         smartapp_manifest_response = await method.execute(payload)
         return smartapp_manifest_response.to_domain()
@@ -1661,6 +1671,47 @@ class Bot:
 
         return botx_api_sync_id.to_domain()
 
+    async def send_smartapp_unread_counter(
+        self,
+        *,
+        bot_id: UUID,
+        group_chat_id: UUID,
+        counter: int,
+        wait_callback: bool = True,
+        callback_timeout: Optional[float] = None,
+    ) -> UUID:
+        """Send SmartApp unread counter.
+
+        :param bot_id: Bot which should perform the request.
+        :param group_chat_id: Target chat id.
+        :param counter: Counter value.
+        :param wait_callback: Block method call until callback received.
+        :param callback_timeout: Callback timeout in seconds (or `None` for
+            endless waiting).
+
+        :return: Sent message's sync_id.
+        """
+
+        method = SmartAppUnreadCounterMethod(
+            bot_id,
+            self._httpx_client,
+            self._bot_accounts_storage,
+            self._callbacks_manager,
+        )
+        payload = BotXAPISmartAppUnreadCounterRequestPayload.from_domain(
+            group_chat_id=group_chat_id,
+            counter=counter,
+        )
+
+        botx_api_sync_id = await method.execute(
+            payload,
+            wait_callback,
+            callback_timeout,
+            self._default_callback_timeout,
+        )
+
+        return botx_api_sync_id.to_domain()
+
     # - Stickers API -
     async def create_sticker_pack(
         self,
@@ -2028,7 +2079,15 @@ class Bot:
         )
         await method.execute(payload)
 
-    def _verify_request(self, headers: Mapping[str, str]) -> None:  # noqa: WPS238
+    def _verify_request(  # noqa: WPS231, WPS238
+        self,
+        headers: Optional[Mapping[str, str]],
+        *,
+        trusted_issuers: Optional[Set[str]] = None,
+    ) -> None:
+        if headers is None:
+            raise RequestHeadersNotProvidedError
+
         authorization_header = headers.get("authorization")
         if not authorization_header:
             raise UnverifiedRequestError("The authorization token was not provided.")
@@ -2065,11 +2124,20 @@ class Bot:
                 leeway=1,
                 options={
                     "verify_aud": False,
+                    "verify_iss": False,
                 },
             )
         except jwt.InvalidTokenError as exc:
             raise UnverifiedRequestError(exc.args[0]) from exc
 
+        issuer = token_payload.get("iss")
+        if issuer is None:
+            raise UnverifiedRequestError('Token is missing the "iss" claim')
+
+        if issuer != bot_account.host:
+            if not trusted_issuers or issuer not in trusted_issuers:
+                raise UnverifiedRequestError("Invalid issuer")
+
     @staticmethod
     def _build_main_collector(
         collectors: Sequence[HandlerCollector],
