@@ -33,29 +33,38 @@ from pybotx.bot.middlewares.exception_middleware import (
     ExceptionMiddleware,
 )
 from pybotx.client.smartapps_api.exceptions import SyncSmartAppEventHandlerNotFoundError
-from pybotx.client.smartapps_api.sync_smartapp_event import (
-    SyncSmartAppEventResponsePayload,
-)
 from pybotx.converters import optional_sequence_to_list
 from pybotx.logger import logger
 from pybotx.models.commands import BotCommand, SystemEvent
 from pybotx.models.message.incoming_message import IncomingMessage
 from pybotx.models.status import BotMenu, StatusRecipient
+from pybotx.models.sync_smartapp_event import BotAPISyncSmartAppEventResponse
 from pybotx.models.system_events.added_to_chat import AddedToChatEvent
 from pybotx.models.system_events.chat_created import ChatCreatedEvent
+from pybotx.models.system_events.chat_deleted_by_user import ChatDeletedByUserEvent
+from pybotx.models.system_events.conference_changed import ConferenceChangedEvent
+from pybotx.models.system_events.conference_created import ConferenceCreatedEvent
+from pybotx.models.system_events.conference_deleted import ConferenceDeletedEvent
 from pybotx.models.system_events.cts_login import CTSLoginEvent
 from pybotx.models.system_events.cts_logout import CTSLogoutEvent
 from pybotx.models.system_events.deleted_from_chat import DeletedFromChatEvent
+from pybotx.models.system_events.event_delete import EventDeleted
 from pybotx.models.system_events.event_edit import EventEdit
 from pybotx.models.system_events.internal_bot_notification import (
     InternalBotNotificationEvent,
 )
 from pybotx.models.system_events.left_from_chat import LeftFromChatEvent
 from pybotx.models.system_events.smartapp_event import SmartAppEvent
+from pybotx.models.system_events.user_joined_to_chat import JoinToChatEvent
 
 if TYPE_CHECKING:  # To avoid circular import
     from pybotx.bot.bot import Bot
 
+MessageHandlerDecorator = Callable[
+    [IncomingMessageHandlerFunc],
+    IncomingMessageHandlerFunc,
+]
+
 
 class HandlerCollector:
     VALID_COMMAND_NAME_RE = re.compile(r"^\/[^\s\/]+$", flags=re.UNICODE)
@@ -76,7 +85,6 @@ class HandlerCollector:
 
     def include(self, *others: "HandlerCollector") -> None:
         """Include other `HandlerCollector`."""
-
         for collector in others:
             self._include_collector(collector)
 
@@ -126,7 +134,7 @@ class HandlerCollector:
         self,
         bot: "Bot",
         smartapp_event: SmartAppEvent,
-    ) -> SyncSmartAppEventResponsePayload:
+    ) -> BotAPISyncSmartAppEventResponse:
         if not isinstance(smartapp_event, SmartAppEvent):
             raise NotImplementedError(
                 f"Unsupported event type for sync smartapp event: `{smartapp_event}`",
@@ -166,7 +174,6 @@ class HandlerCollector:
         middlewares: Optional[Sequence[Middleware]] = None,
     ) -> Callable[[IncomingMessageHandlerFunc], IncomingMessageHandlerFunc]:
         """Decorate command handler."""
-
         if not self.VALID_COMMAND_NAME_RE.match(command_name):
             raise ValueError("Command should start with '/' and doesn't include spaces")
 
@@ -193,16 +200,14 @@ class HandlerCollector:
     def default_message_handler(
         self,
         handler_func: IncomingMessageHandlerFunc,
-    ) -> IncomingMessageHandlerFunc:
-        ...  # noqa: WPS428
+    ) -> IncomingMessageHandlerFunc: ...  # noqa: WPS428, E704
 
     @overload
     def default_message_handler(
         self,
         *,
         middlewares: Optional[Sequence[Middleware]] = None,
-    ) -> Callable[[IncomingMessageHandlerFunc], IncomingMessageHandlerFunc]:
-        ...  # noqa: WPS428
+    ) -> MessageHandlerDecorator: ...  # noqa: WPS428, E704
 
     def default_message_handler(  # noqa: WPS320
         self,
@@ -237,9 +242,15 @@ class HandlerCollector:
         handler_func: HandlerFunc[ChatCreatedEvent],
     ) -> HandlerFunc[ChatCreatedEvent]:
         """Decorate `chat_created` event handler."""
-
         self._system_event(ChatCreatedEvent, handler_func)
+        return handler_func
 
+    def chat_deleted_by_user(
+        self,
+        handler_func: HandlerFunc[ChatDeletedByUserEvent],
+    ) -> HandlerFunc[ChatDeletedByUserEvent]:
+        """Decorate `chat_deleted_by_user` event handler."""
+        self._system_event(ChatDeletedByUserEvent, handler_func)
         return handler_func
 
     def added_to_chat(
@@ -247,9 +258,7 @@ class HandlerCollector:
         handler_func: HandlerFunc[AddedToChatEvent],
     ) -> HandlerFunc[AddedToChatEvent]:
         """Decorate `added_to_chat` event handler."""
-
         self._system_event(AddedToChatEvent, handler_func)
-
         return handler_func
 
     def deleted_from_chat(
@@ -257,9 +266,7 @@ class HandlerCollector:
         handler_func: HandlerFunc[DeletedFromChatEvent],
     ) -> HandlerFunc[DeletedFromChatEvent]:
         """Decorate `deleted_from_chat` event handler."""
-
         self._system_event(DeletedFromChatEvent, handler_func)
-
         return handler_func
 
     def left_from_chat(
@@ -267,9 +274,15 @@ class HandlerCollector:
         handler_func: HandlerFunc[LeftFromChatEvent],
     ) -> HandlerFunc[LeftFromChatEvent]:
         """Decorate `left_from_chat` event handler."""
-
         self._system_event(LeftFromChatEvent, handler_func)
+        return handler_func
 
+    def user_joined_to_chat(
+        self,
+        handler_func: HandlerFunc[JoinToChatEvent],
+    ) -> HandlerFunc[JoinToChatEvent]:
+        """Decorate `user_joined_to_chat` event handler."""
+        self._system_event(JoinToChatEvent, handler_func)
         return handler_func
 
     def internal_bot_notification(
@@ -277,9 +290,7 @@ class HandlerCollector:
         handler_func: HandlerFunc[InternalBotNotificationEvent],
     ) -> HandlerFunc[InternalBotNotificationEvent]:
         """Decorate `internal_bot_notification` event handler."""
-
         self._system_event(InternalBotNotificationEvent, handler_func)
-
         return handler_func
 
     def cts_login(
@@ -287,9 +298,7 @@ class HandlerCollector:
         handler_func: HandlerFunc[CTSLoginEvent],
     ) -> HandlerFunc[CTSLoginEvent]:
         """Decorate `cts_login` event handler."""
-
         self._system_event(CTSLoginEvent, handler_func)
-
         return handler_func
 
     def cts_logout(
@@ -297,9 +306,7 @@ class HandlerCollector:
         handler_func: HandlerFunc[CTSLogoutEvent],
     ) -> HandlerFunc[CTSLogoutEvent]:
         """Decorate `cts_logout` event handler."""
-
         self._system_event(CTSLogoutEvent, handler_func)
-
         return handler_func
 
     def event_edit(
@@ -307,9 +314,39 @@ class HandlerCollector:
         handler_func: HandlerFunc[EventEdit],
     ) -> HandlerFunc[EventEdit]:
         """Decorate `event edit` event handler."""
-
         self._system_event(EventEdit, handler_func)
+        return handler_func
 
+    def event_deleted(
+        self,
+        handler_func: HandlerFunc[EventDeleted],
+    ) -> HandlerFunc[EventDeleted]:
+        """Decorate `event deleted` event handler."""
+        self._system_event(EventDeleted, handler_func)
+        return handler_func
+
+    def conference_changed(
+        self,
+        handler_func: HandlerFunc[ConferenceChangedEvent],
+    ) -> HandlerFunc[ConferenceChangedEvent]:
+        """Decorate `conference changed` event handler."""
+        self._system_event(ConferenceChangedEvent, handler_func)
+        return handler_func
+
+    def conference_created(
+        self,
+        handler_func: HandlerFunc[ConferenceCreatedEvent],
+    ) -> HandlerFunc[ConferenceCreatedEvent]:
+        """Decorate `conference created` event handler."""
+        self._system_event(ConferenceCreatedEvent, handler_func)
+        return handler_func
+
+    def conference_deleted(
+        self,
+        handler_func: HandlerFunc[ConferenceDeletedEvent],
+    ) -> HandlerFunc[ConferenceDeletedEvent]:
+        """Decorate `conference deleted` event handler."""
+        self._system_event(ConferenceDeletedEvent, handler_func)
         return handler_func
 
     def smartapp_event(
@@ -317,9 +354,7 @@ class HandlerCollector:
         handler_func: HandlerFunc[SmartAppEvent],
     ) -> HandlerFunc[SmartAppEvent]:
         """Decorate `smartapp` event handler."""
-
         self._system_event(SmartAppEvent, handler_func)
-
         return handler_func
 
     def sync_smartapp_event(
