@@ -220,7 +220,10 @@ def convert_api_attachment_to_domain(  # noqa: WPS212
     attachment_type = convert_attachment_type_to_domain(api_attachment.type)
 
     if attachment_type == AttachmentTypes.IMAGE:
-        attachment_type = cast(Literal[AttachmentTypes.IMAGE], attachment_type)
+        attachment_type = cast(  # type: ignore[redundant-cast]
+            Literal[AttachmentTypes.IMAGE],
+            attachment_type,
+        )
         api_attachment = cast(BotAPIAttachmentImage, api_attachment)
         content = decode_rfc2397(api_attachment.data.content)
 
@@ -233,7 +236,10 @@ def convert_api_attachment_to_domain(  # noqa: WPS212
         )
 
     if attachment_type == AttachmentTypes.VIDEO:
-        attachment_type = cast(Literal[AttachmentTypes.VIDEO], attachment_type)
+        attachment_type = cast(  # type: ignore[redundant-cast]
+            Literal[AttachmentTypes.VIDEO],
+            attachment_type,
+        )
         api_attachment = cast(BotAPIAttachmentVideo, api_attachment)
         content = decode_rfc2397(api_attachment.data.content)
 
@@ -247,7 +253,10 @@ def convert_api_attachment_to_domain(  # noqa: WPS212
         )
 
     if attachment_type == AttachmentTypes.DOCUMENT:
-        attachment_type = cast(Literal[AttachmentTypes.DOCUMENT], attachment_type)
+        attachment_type = cast(  # type: ignore[redundant-cast]
+            Literal[AttachmentTypes.DOCUMENT],
+            attachment_type,
+        )
         api_attachment = cast(BotAPIAttachmentDocument, api_attachment)
         content = decode_rfc2397(api_attachment.data.content)
 
@@ -260,7 +269,10 @@ def convert_api_attachment_to_domain(  # noqa: WPS212
         )
 
     if attachment_type == AttachmentTypes.VOICE:
-        attachment_type = cast(Literal[AttachmentTypes.VOICE], attachment_type)
+        attachment_type = cast(  # type: ignore[redundant-cast]
+            Literal[AttachmentTypes.VOICE],
+            attachment_type,
+        )
         api_attachment = cast(BotAPIAttachmentVoice, api_attachment)
         content = decode_rfc2397(api_attachment.data.content)
         attachment_extension = get_attachment_extension_from_encoded_content(
@@ -277,7 +289,10 @@ def convert_api_attachment_to_domain(  # noqa: WPS212
         )
 
     if attachment_type == AttachmentTypes.LOCATION:
-        attachment_type = cast(Literal[AttachmentTypes.LOCATION], attachment_type)
+        attachment_type = cast(  # type: ignore[redundant-cast]
+            Literal[AttachmentTypes.LOCATION],
+            attachment_type,
+        )
         api_attachment = cast(BotAPIAttachmentLocation, api_attachment)
 
         return Location(
@@ -288,7 +303,10 @@ def convert_api_attachment_to_domain(  # noqa: WPS212
         )
 
     if attachment_type == AttachmentTypes.CONTACT:
-        attachment_type = cast(Literal[AttachmentTypes.CONTACT], attachment_type)
+        attachment_type = cast(  # type: ignore[redundant-cast]
+            Literal[AttachmentTypes.CONTACT],
+            attachment_type,
+        )
         api_attachment = cast(BotAPIAttachmentContact, api_attachment)
 
         return Contact(
@@ -296,7 +314,6 @@ def convert_api_attachment_to_domain(  # noqa: WPS212
         )
 
     if attachment_type == AttachmentTypes.LINK:
-        attachment_type = cast(Literal[AttachmentTypes.LINK], attachment_type)
         api_attachment = cast(BotAPIAttachmentLink, api_attachment)
 
         return Link(
@@ -307,7 +324,6 @@ def convert_api_attachment_to_domain(  # noqa: WPS212
         )
 
     if attachment_type == AttachmentTypes.STICKER:
-        attachment_type = cast(Literal[AttachmentTypes.STICKER], attachment_type)
         api_attachment = cast(BotAPIAttachmentSticker, api_attachment)
 
         return Sticker(
